@@ -1,5 +1,5 @@
 /* ************************************************************************
- * Copyright (C) 2018-2024 Advanced Micro Devices, Inc. All rights reserved.
+ * Copyright (C) 2018-2025 Advanced Micro Devices, Inc. All rights reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -56,12 +56,8 @@ void testing_trtri_strided_batched_bad_arg(const Arguments& arg)
     const rocblas_diagonal diag = rocblas_diagonal_non_unit;
 
     // Allocate device memory
-    device_strided_batch_matrix<T> dA(N, N, lda, stride_A, batch_count);
-    device_strided_batch_matrix<T> dinvA(N, N, lda, stride_A, batch_count);
-
-    // Check device memory allocation
-    CHECK_DEVICE_ALLOCATION(dA.memcheck());
-    CHECK_DEVICE_ALLOCATION(dinvA.memcheck());
+    DEVICE_MEMCHECK(device_strided_batch_matrix<T>, dA, (N, N, lda, stride_A, batch_count));
+    DEVICE_MEMCHECK(device_strided_batch_matrix<T>, dinvA, (N, N, lda, stride_A, batch_count));
 
     EXPECT_ROCBLAS_STATUS(rocblas_trtri_strided_batched_fn(handle,
                                                            rocblas_fill_full,
@@ -173,20 +169,12 @@ void testing_trtri_strided_batched(const Arguments& arg)
     }
 
     // Naming: dK is in GPU (device) memory. hK is in CPU (host) memory
-    host_strided_batch_matrix<T> hA(N, N, lda, stride_A, batch_count);
-    host_strided_batch_matrix<T> hB(N, N, lda, stride_A, batch_count);
-
-    // Check host memory allocation
-    CHECK_HIP_ERROR(hA.memcheck());
-    CHECK_HIP_ERROR(hB.memcheck());
+    HOST_MEMCHECK(host_strided_batch_matrix<T>, hA, (N, N, lda, stride_A, batch_count));
+    HOST_MEMCHECK(host_strided_batch_matrix<T>, hB, (N, N, lda, stride_A, batch_count));
 
     // Allocate device memory
-    device_strided_batch_matrix<T> dA(N, N, lda, stride_A, batch_count);
-    device_strided_batch_matrix<T> dinvA(N, N, lda, stride_A, batch_count);
-
-    // Check device memory allocation
-    CHECK_DEVICE_ALLOCATION(dA.memcheck());
-    CHECK_DEVICE_ALLOCATION(dinvA.memcheck());
+    DEVICE_MEMCHECK(device_strided_batch_matrix<T>, dA, (N, N, lda, stride_A, batch_count));
+    DEVICE_MEMCHECK(device_strided_batch_matrix<T>, dinvA, (N, N, lda, stride_A, batch_count));
 
     // Initial Data on CPU
     // Explicitly set the unused side of matrix `hA` to 0 when using it for temp storage.
@@ -226,25 +214,6 @@ void testing_trtri_strided_batched(const Arguments& arg)
     gpu_time_used = cpu_time_used = 0.0;
     double rocblas_error_out, rocblas_error_in;
 
-    if(!ROCBLAS_REALLOC_ON_DEMAND)
-    {
-        // Compute size
-        CHECK_ROCBLAS_ERROR(rocblas_start_device_memory_size_query(handle));
-
-        CHECK_ALLOC_QUERY(rocblas_trtri_strided_batched_fn(
-            handle, uplo, diag, N, dA, lda, stride_A, dinvA, lda, stride_A, batch_count));
-
-        // Test in place
-        CHECK_ALLOC_QUERY(rocblas_trtri_strided_batched_fn(
-            handle, uplo, diag, N, dA, lda, stride_A, dA, lda, stride_A, batch_count));
-
-        size_t size;
-        CHECK_ROCBLAS_ERROR(rocblas_stop_device_memory_size_query(handle, &size));
-
-        // Allocate memory
-        CHECK_ROCBLAS_ERROR(rocblas_set_device_memory_size(handle, size));
-    }
-
     /* =====================================================================
            ROCBLAS
     =================================================================== */
@@ -259,11 +228,13 @@ void testing_trtri_strided_batched(const Arguments& arg)
 
             if(arg.repeatability_check)
             {
-                host_strided_batch_matrix<T> hA_copy(N, N, lda, stride_A, batch_count);
+                HOST_MEMCHECK(
+                    host_strided_batch_matrix<T>, hA_copy, (N, N, lda, stride_A, batch_count));
                 CHECK_HIP_ERROR(hA.transfer_from(dinvA));
                 // multi-GPU support
                 int device_id, device_count;
-                CHECK_HIP_ERROR(hipGetDeviceCount(&device_count));
+                CHECK_HIP_ERROR(limit_device_count(device_count, (int)arg.devices));
+
                 for(int dev_id = 0; dev_id < device_count; dev_id++)
                 {
                     CHECK_HIP_ERROR(hipGetDevice(&device_id));
@@ -274,12 +245,12 @@ void testing_trtri_strided_batched(const Arguments& arg)
                     rocblas_local_handle handle_copy{arg};
 
                     //Allocate device memory in new device
-                    device_strided_batch_matrix<T> dA_copy(N, N, lda, stride_A, batch_count);
-                    device_strided_batch_matrix<T> dinvA_copy(N, N, lda, stride_A, batch_count);
-
-                    // Check device memory allocation
-                    CHECK_DEVICE_ALLOCATION(dA_copy.memcheck());
-                    CHECK_DEVICE_ALLOCATION(dinvA_copy.memcheck());
+                    DEVICE_MEMCHECK(device_strided_batch_matrix<T>,
+                                    dA_copy,
+                                    (N, N, lda, stride_A, batch_count));
+                    DEVICE_MEMCHECK(device_strided_batch_matrix<T>,
+                                    dinvA_copy,
+                                    (N, N, lda, stride_A, batch_count));
 
                     for(int runs = 0; runs < arg.iters; runs++)
                     {
@@ -310,8 +281,8 @@ void testing_trtri_strided_batched(const Arguments& arg)
             rocblas_stride subStride       = 0;
             rocblas_int    sub_batch_count = 1;
 
-            size_t           work_el = rocblas_internal_trtri_temp_elements(N, batch_count);
-            device_vector<T> workspace(work_el);
+            size_t work_el = rocblas_internal_trtri_temp_elements(N, batch_count);
+            DEVICE_MEMCHECK(device_vector<T>, workspace, (work_el));
 
             CHECK_ROCBLAS_ERROR(rocblas_internal_trtri_template(handle,
                                                                 uplo,
@@ -346,8 +317,8 @@ void testing_trtri_strided_batched(const Arguments& arg)
             rocblas_stride subStride       = 0;
             rocblas_int    sub_batch_count = 1;
 
-            size_t           work_el = rocblas_internal_trtri_temp_elements(N, batch_count);
-            device_vector<T> workspace(work_el);
+            size_t work_el = rocblas_internal_trtri_temp_elements(N, batch_count);
+            DEVICE_MEMCHECK(device_vector<T>, workspace, (work_el));
 
             CHECK_ROCBLAS_ERROR(rocblas_internal_trtri_template(handle,
                                                                 uplo,
@@ -381,7 +352,7 @@ void testing_trtri_strided_batched(const Arguments& arg)
         for(size_t b = 0; b < batch_count; b++)
         {
             // CBLAS doesn't have trtri implementation so using the LAPACK trtri
-            lapack_xtrtri<T>(char_uplo, char_diag, N, hB[b], lda);
+            ref_lapack_xtrtri<T>(char_uplo, char_diag, N, hB[b], lda);
         }
 
         if(arg.timing)
