@@ -1,5 +1,5 @@
 /* ************************************************************************
- * Copyright (C) 2022-2023 Advanced Micro Devices, Inc. All rights reserved.
+ * Copyright (C) 2022-2025 Advanced Micro Devices, Inc. All rights reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -22,6 +22,7 @@
 
 #pragma once
 
+#include "device_macros.hpp"
 #include "int64_helpers.hpp"
 #include "utility.hpp"
 #include <hip/hip_runtime.h>
@@ -42,6 +43,7 @@ __inline__ __device__ T rocblas_wavefront_reduce(T val)
 {
     constexpr int WFBITS = rocblas_log2ui(N);
     int           offset = 1 << (WFBITS - 1);
+#pragma unroll
     for(int i = 0; i < WFBITS; i++)
     {
         val += __shfl_down(val, offset);
@@ -55,6 +57,7 @@ __inline__ __device__ rocblas_float_complex rocblas_wavefront_reduce(rocblas_flo
 {
     constexpr int WFBITS = rocblas_log2ui(N);
     int           offset = 1 << (WFBITS - 1);
+#pragma unroll
     for(int i = 0; i < WFBITS; i++)
     {
         val.real(val.real() + __shfl_down(val.real(), offset));
@@ -69,6 +72,7 @@ __inline__ __device__ rocblas_double_complex rocblas_wavefront_reduce(rocblas_do
 {
     constexpr int WFBITS = rocblas_log2ui(N);
     int           offset = 1 << (WFBITS - 1);
+#pragma unroll
     for(int i = 0; i < WFBITS; i++)
     {
         val.real(val.real() + __shfl_down(val.real(), offset));
@@ -88,6 +92,7 @@ __inline__ __device__ rocblas_bfloat16 rocblas_wavefront_reduce(rocblas_bfloat16
     } tmp;
     constexpr int WFBITS = rocblas_log2ui(N);
     int           offset = 1 << (WFBITS - 1);
+#pragma unroll
     for(int i = 0; i < WFBITS; i++)
     {
         tmp.h = val;
@@ -108,6 +113,7 @@ __inline__ __device__ rocblas_half rocblas_wavefront_reduce(rocblas_half val)
     } tmp;
     constexpr int WFBITS = rocblas_log2ui(N);
     int           offset = 1 << (WFBITS - 1);
+#pragma unroll
     for(int i = 0; i < WFBITS; i++)
     {
         tmp.h = val;
@@ -118,26 +124,30 @@ __inline__ __device__ rocblas_half rocblas_wavefront_reduce(rocblas_half val)
     return val;
 }
 
-template <int NB, typename T>
+template <int WARP, int NB, typename T>
 __inline__ __device__ T rocblas_dot_block_reduce(T val)
 {
-    __shared__ T psums[warpSize];
+    __shared__ T psums[WARP];
 
-    rocblas_int wavefront = threadIdx.x / warpSize;
-    rocblas_int wavelet   = threadIdx.x % warpSize;
+    rocblas_int wavefront = threadIdx.x / WARP;
+    rocblas_int wavelet   = threadIdx.x % WARP;
 
     if(wavefront == 0)
         psums[wavelet] = T(0);
     __syncthreads();
 
-    val = rocblas_wavefront_reduce<warpSize>(val); // sum over wavefront
+    val = rocblas_wavefront_reduce<WARP>(val); // sum over wavefront
     if(wavelet == 0)
         psums[wavefront] = val; // store sum for wavefront
 
     __syncthreads(); // Wait for all wavefront reductions
 
     // ensure wavefront was run
-    static constexpr rocblas_int num_wavefronts = NB / warpSize;
+    static constexpr rocblas_int num_wavefronts = NB / WARP;
+
+    // single warp of either size will doing final sum so test with smaller constraint
+    static_assert(num_wavefronts <= WARP_32);
+
     val = (threadIdx.x < num_wavefronts) ? psums[wavelet] : T(0);
     if(wavefront == 0)
         val = rocblas_wavefront_reduce<num_wavefronts>(val); // sum wavefront sums
@@ -161,33 +171,27 @@ inline size_t rocblas_reduction_kernel_pass_count(int64_t n)
     return size_t(passes);
 }
 
-/*! \brief rocblas_reduction_batched_kernel_workspace_size
-    Work area for reduction must be at lease sizeof(To) * (blocks + 1) * batch_count.
-    Additional passes add to workspace requirement for ILP64 subdivisions
-
-    @param[in]
-    outputType To*
-        Type of output values
-    @param[in]
-    batch_count rocblas_int
-        Number of batches
-    ********************************************************************/
 template <typename API_INT, int NB, typename To>
-size_t rocblas_reduction_kernel_workspace_size(API_INT n, API_INT batch_count = 1)
+size_t rocblas_single_pass_reduction_workspace_size(API_INT n, API_INT batch_count = 1)
 {
     if(n <= 0)
         n = 1; // allow for return value of empty set
     if(batch_count <= 0)
         batch_count = 1;
 
-    auto blocks = rocblas_reduction_kernel_block_count<API_INT>(n, NB);
+    API_INT n_chunked = n;
+    if constexpr(std::is_same_v<API_INT, int64_t>)
+    {
+        // algorithm in launcher required to always chunk, no 32bit pass-through for n < int32 max
+        n_chunked = std::min(n_chunked, c_i64_grid_X_chunk);
+    }
+    auto blocks = rocblas_reduction_kernel_block_count<API_INT>(n_chunked, NB);
 
     if constexpr(std::is_same_v<API_INT, int64_t>)
     {
-        auto    passes  = rocblas_reduction_kernel_pass_count(n);
         int64_t batches = std::min(batch_count, c_i64_grid_YZ_chunk);
 
-        return sizeof(To) * (blocks + 1) * batches * passes;
+        return sizeof(To) * (blocks + 1) * batches;
     }
     else
     {
@@ -196,43 +200,173 @@ size_t rocblas_reduction_kernel_workspace_size(API_INT n, API_INT batch_count =
     }
 }
 
-/*! \brief rocblas_reduction_batched_kernel_workspace_size
-    Work area for reduction must be at lease sizeof(To) * (blocks + 1) * batch_count
+/*! \brief rocblas_multi_pass_reduction_workspace_size
+    Work area where each chunk is fully reduced to single value
+    ********************************************************************/
+template <typename API_INT, int NB, typename To>
+size_t rocblas_multi_pass_reduction_workspace_size(API_INT n, API_INT batch_count = 1)
+{
+    if(n <= 0)
+        n = 1; // allow for return value of empty set
+    if(batch_count <= 0)
+        batch_count = 1;
+
+    API_INT n_chunked = n;
+    if constexpr(std::is_same_v<API_INT, int64_t>)
+    {
+        // algorithm in launcher required to always chunk, no 32bit pass-through for n < int32 max
+        n_chunked = std::min(n_chunked, c_i64_grid_X_chunk);
+    }
+    auto blocks = rocblas_reduction_kernel_block_count<API_INT>(n_chunked, NB);
+
+    if constexpr(std::is_same_v<API_INT, int64_t>)
+    {
+        auto    passes  = rocblas_reduction_kernel_pass_count(n);
+        int64_t batches = std::min(batch_count, c_i64_grid_YZ_chunk);
+
+        // each pass is reduced so only addition of passes * batches
+        return sizeof(To) * ((blocks + 1) * batches + passes * batches);
+    }
+    else
+    {
+        // original API
+        return sizeof(To) * (blocks + 1) * batch_count;
+    }
+}
+
+/*! \brief rocblas_reduction_workspace_non_chunked_size
+    Work area for reduction must be at lease sizeof(To) * (blocks + 1) * batch_count.
 
     @param[in]
-    outputType To*
+    outputType To
         Type of output values
     @param[in]
     batch_count rocblas_int
         Number of batches
     ********************************************************************/
 template <typename API_INT, int NB, typename To>
-size_t rocblas_reduction_kernel_workspace_size(API_INT n, API_INT batch_count, To* output_type)
+size_t rocblas_reduction_workspace_non_chunked_size(API_INT n, API_INT batch_count = 1)
 {
-    return rocblas_reduction_kernel_workspace_size<API_INT, NB, To>(n, batch_count);
+    if(n <= 0)
+        n = 1; // allow for return value of empty set
+    if(batch_count <= 0)
+        batch_count = 1;
+
+    auto blocks = rocblas_reduction_kernel_block_count<API_INT>(n, NB);
+
+    // original API
+
+    return sizeof(To) * (blocks + 1) * batch_count;
+}
+
+/*! \brief rocblas_reduction_kernel_part2
+    gathers all the partial results in workspace and finishes the final reduction.
+    ********************************************************************/
+template <int NB, int WIN, typename FINALIZE, typename V, typename T = V>
+ROCBLAS_KERNEL(NB)
+rocblas_reduction_kernel_part2(int n_sums, V* __restrict__ in, T* __restrict__ out)
+{
+    V sum = 0;
+
+    size_t offset = size_t(blockIdx.x) * n_sums;
+    in += offset;
+
+    int inc = NB * WIN;
+
+    int i         = threadIdx.x * WIN;
+    int remainder = n_sums % WIN;
+    int end       = n_sums - remainder;
+    for(; i < end; i += inc) // cover all sums as 1 block
+    {
+        for(int j = 0; j < WIN; j++)
+            sum += in[i + j];
+    }
+    if(threadIdx.x < remainder)
+    {
+        sum += in[n_sums - 1 - threadIdx.x];
+    }
+
+    if(warpSize == WARP_32)
+        sum = rocblas_dot_block_reduce<WARP_32, NB>(sum);
+    else
+        sum = rocblas_dot_block_reduce<WARP_64, NB>(sum);
+
+    if(threadIdx.x == 0)
+        out[blockIdx.x] = T(FINALIZE{}(sum));
+}
+
+/*! \brief rocblas_reduction_batched_kernel_workspace_size
+    Work area for reductions where full reduction to single value occurs
+    Additional passes add to workspace requirement for ILP64 subdivisions but size limited to chunks
+
+    @param[in]
+    outputType To
+        Type of output values
+    @param[in]
+    batch_count rocblas_int
+        Number of batches
+    ********************************************************************/
+template <typename API_INT, int NB, typename To>
+size_t
+    rocblas_reduction_workspace_size(API_INT n, API_INT incx, API_INT incy, API_INT batch_count = 1)
+{
+    if(n <= 0)
+        n = 1; // allow for return value of empty set
+    if(batch_count <= 0)
+        batch_count = 1;
+
+    if constexpr(std::is_same_v<API_INT, int64_t>)
+    {
+        // must track _64 kernel decision code
+
+        if(std::abs(incx) <= c_i32_max && std::abs(incy) <= c_i32_max && n <= c_i32_max
+           && batch_count < c_i64_grid_YZ_chunk)
+        {
+            // reusing 32- bit API
+            return rocblas_reduction_workspace_non_chunked_size<API_INT, NB, To>(n, batch_count);
+        }
+        else
+        {
+            // algorithm in launcher required to always chunk for these sizes or workspace too small
+            return rocblas_multi_pass_reduction_workspace_size<API_INT, NB, To>(n, batch_count);
+        }
+    }
+    else
+    {
+        // original API
+        return rocblas_reduction_workspace_non_chunked_size<API_INT, NB, To>(n, batch_count);
+    }
+}
+
+template <typename API_INT, int NB, typename To>
+size_t rocblas_reduction_workspace_size(
+    API_INT n, API_INT incx, API_INT incy, API_INT batch_count, To* output_type)
+{
+    return rocblas_reduction_workspace_size<API_INT, NB, To>(n, incx, incy, batch_count);
 }
 
 template <typename API_INT, int NB>
-size_t
-    rocblas_reduction_kernel_workspace_size(API_INT n, API_INT batch_count, rocblas_datatype type)
+size_t rocblas_reduction_workspace_size(
+    API_INT n, API_INT incx, API_INT incy, API_INT batch_count, rocblas_datatype type)
 {
     switch(type)
     {
     case rocblas_datatype_f16_r:
-        return rocblas_reduction_kernel_workspace_size<API_INT, NB, rocblas_half>(n, batch_count);
+        return rocblas_reduction_workspace_size<API_INT, NB, rocblas_half>(
+            n, incx, incy, batch_count);
     case rocblas_datatype_bf16_r:
-        return rocblas_reduction_kernel_workspace_size<API_INT, NB, rocblas_bfloat16>(n,
-                                                                                      batch_count);
+        return rocblas_reduction_workspace_size<API_INT, NB, rocblas_bfloat16>(
+            n, incx, incy, batch_count);
     case rocblas_datatype_f32_r:
-        return rocblas_reduction_kernel_workspace_size<API_INT, NB, float>(n, batch_count);
+        return rocblas_reduction_workspace_size<API_INT, NB, float>(n, incx, incy, batch_count);
     case rocblas_datatype_f64_r:
-        return rocblas_reduction_kernel_workspace_size<API_INT, NB, double>(n, batch_count);
+        return rocblas_reduction_workspace_size<API_INT, NB, double>(n, incx, incy, batch_count);
     case rocblas_datatype_f32_c:
-        return rocblas_reduction_kernel_workspace_size<API_INT, NB, rocblas_float_complex>(
-            n, batch_count);
+        return rocblas_reduction_workspace_size<API_INT, NB, rocblas_float_complex>(
+            n, incx, incy, batch_count);
     case rocblas_datatype_f64_c:
-        return rocblas_reduction_kernel_workspace_size<API_INT, NB, rocblas_double_complex>(
-            n, batch_count);
+        return rocblas_reduction_workspace_size<API_INT, NB, rocblas_double_complex>(
+            n, incx, incy, batch_count);
     default:
         return 0;
     }
