@@ -1,5 +1,5 @@
 /* ************************************************************************
- * Copyright (C) 2016-2024 Advanced Micro Devices, Inc. All rights reserved.
+ * Copyright (C) 2016-2025 Advanced Micro Devices, Inc. All rights reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -78,22 +78,14 @@ namespace
         if(!handle)
             return rocblas_status_invalid_handle;
 
-        if constexpr(std::is_same_v<API_INT, int>)
-        {
-            if(batch_count > c_YZ_grid_launch_limit && handle->isYZGridDim16bit())
-            {
-                return rocblas_status_invalid_size;
-            }
-        }
-
         size_t dev_bytes = ROCBLAS_API(rocblas_internal_gemv_kernel_workspace_size)<Tex>(
             transA, m, n, batch_count);
         if(handle->is_device_memory_size_query())
             return handle->set_optimal_device_memory_size(dev_bytes);
 
-        auto layer_mode     = handle->layer_mode;
-        auto check_numerics = handle->check_numerics;
-
+        auto                    layer_mode     = handle->layer_mode;
+        auto                    check_numerics = handle->check_numerics;
+        rocblas_internal_logger logger;
         if(layer_mode
            & (rocblas_layer_mode_log_trace | rocblas_layer_mode_log_bench
               | rocblas_layer_mode_log_profile))
@@ -101,112 +93,112 @@ namespace
             auto transA_letter = rocblas_transpose_letter(transA);
 
             if(layer_mode & rocblas_layer_mode_log_trace)
-                log_trace(handle,
-                          rocblas_gemv_name<Ti, To>,
-                          transA,
-                          m,
-                          n,
-                          LOG_TRACE_SCALAR_VALUE(handle, alpha),
-                          A,
-                          lda,
-                          strideA,
-                          x,
-                          incx,
-                          stridex,
-                          LOG_TRACE_SCALAR_VALUE(handle, beta),
-                          y,
-                          incy,
-                          stridey,
-                          batch_count);
+                logger.log_trace(handle,
+                                 rocblas_gemv_name<Ti, To>,
+                                 transA,
+                                 m,
+                                 n,
+                                 LOG_TRACE_SCALAR_VALUE(handle, alpha),
+                                 A,
+                                 lda,
+                                 strideA,
+                                 x,
+                                 incx,
+                                 stridex,
+                                 LOG_TRACE_SCALAR_VALUE(handle, beta),
+                                 y,
+                                 incy,
+                                 stridey,
+                                 batch_count);
 
             if(layer_mode & rocblas_layer_mode_log_bench)
             {
                 if constexpr(std::is_same<Ti, rocblas_half>{}
                              || std::is_same<Ti, rocblas_bfloat16>{})
                 {
-                    log_bench(handle,
-                              ROCBLAS_API_BENCH " -f gemv_strided_batched --a_type",
-                              rocblas_precision_string<Ti>,
-                              "--c_type",
-                              rocblas_precision_string<To>,
-                              "--compute_type",
-                              rocblas_precision_string<Tex>,
-                              "--transposeA",
-                              transA_letter,
-                              "-m",
-                              m,
-                              "-n",
-                              n,
-                              LOG_BENCH_SCALAR_VALUE(handle, alpha),
-                              "--lda",
-                              lda,
-                              "--stride_a",
-                              strideA,
-                              "--incx",
-                              incx,
-                              "--stride_x",
-                              stridex,
-                              LOG_BENCH_SCALAR_VALUE(handle, beta),
-                              "--incy",
-                              incy,
-                              "--stride_y",
-                              stridey,
-                              "--batch_count",
-                              batch_count);
+                    logger.log_bench(handle,
+                                     ROCBLAS_API_BENCH " -f gemv_strided_batched --a_type",
+                                     rocblas_precision_string<Ti>,
+                                     "--c_type",
+                                     rocblas_precision_string<To>,
+                                     "--compute_type",
+                                     rocblas_precision_string<Tex>,
+                                     "--transposeA",
+                                     transA_letter,
+                                     "-m",
+                                     m,
+                                     "-n",
+                                     n,
+                                     LOG_BENCH_SCALAR_VALUE(handle, alpha),
+                                     "--lda",
+                                     lda,
+                                     "--stride_a",
+                                     strideA,
+                                     "--incx",
+                                     incx,
+                                     "--stride_x",
+                                     stridex,
+                                     LOG_BENCH_SCALAR_VALUE(handle, beta),
+                                     "--incy",
+                                     incy,
+                                     "--stride_y",
+                                     stridey,
+                                     "--batch_count",
+                                     batch_count);
                 }
                 else
                 {
-                    log_bench(handle,
-                              ROCBLAS_API_BENCH " -f gemv_strided_batched -r",
-                              rocblas_precision_string<Ti>,
-                              "--transposeA",
-                              transA_letter,
-                              "-m",
-                              m,
-                              "-n",
-                              n,
-                              LOG_BENCH_SCALAR_VALUE(handle, alpha),
-                              "--lda",
-                              lda,
-                              "--stride_a",
-                              strideA,
-                              "--incx",
-                              incx,
-                              "--stride_x",
-                              stridex,
-                              LOG_BENCH_SCALAR_VALUE(handle, beta),
-                              "--incy",
-                              incy,
-                              "--stride_y",
-                              stridey,
-                              "--batch_count",
-                              batch_count);
+                    logger.log_bench(handle,
+                                     ROCBLAS_API_BENCH " -f gemv_strided_batched -r",
+                                     rocblas_precision_string<Ti>,
+                                     "--transposeA",
+                                     transA_letter,
+                                     "-m",
+                                     m,
+                                     "-n",
+                                     n,
+                                     LOG_BENCH_SCALAR_VALUE(handle, alpha),
+                                     "--lda",
+                                     lda,
+                                     "--stride_a",
+                                     strideA,
+                                     "--incx",
+                                     incx,
+                                     "--stride_x",
+                                     stridex,
+                                     LOG_BENCH_SCALAR_VALUE(handle, beta),
+                                     "--incy",
+                                     incy,
+                                     "--stride_y",
+                                     stridey,
+                                     "--batch_count",
+                                     batch_count);
                 }
             }
 
             if(layer_mode & rocblas_layer_mode_log_profile)
-                log_profile(handle,
-                            rocblas_gemv_name<Ti, To>,
-                            "transA",
-                            transA_letter,
-                            "M",
-                            m,
-                            "N",
-                            n,
-                            "lda",
-                            lda,
-                            "stride_a",
-                            strideA,
-                            "incx",
-                            incx,
-                            "stride_x",
-                            stridex,
-                            "incy",
-                            incy,
-                            "stride_y",
-                            stridey,
-                            "batch_count",
-                            batch_count);
+                logger.log_profile(handle,
+                                   rocblas_gemv_name<Ti, To>,
+                                   "transA",
+                                   transA_letter,
+                                   "M",
+                                   m,
+                                   "N",
+                                   n,
+                                   "lda",
+                                   lda,
+                                   "stride_a",
+                                   strideA,
+                                   "incx",
+                                   incx,
+                                   "stride_x",
+                                   stridex,
+                                   "incy",
+                                   incy,
+                                   "stride_y",
+                                   stridey,
+                                   "batch_count",
+                                   batch_count);
         }
 
         rocblas_status arg_status = rocblas_internal_gemv_arg_check(handle,
