@@ -1,5 +1,5 @@
 /* ************************************************************************
- * Copyright (C) 2016-2023 Advanced Micro Devices, Inc. All rights reserved.
+ * Copyright (C) 2016-2025 Advanced Micro Devices, Inc. All rights reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -90,72 +90,73 @@ namespace
             return rocblas_status_invalid_handle;
         RETURN_ZERO_DEVICE_MEMORY_SIZE_IF_QUERIED(handle);
 
-        auto layer_mode     = handle->layer_mode;
-        auto check_numerics = handle->check_numerics;
+        auto                    layer_mode     = handle->layer_mode;
+        auto                    check_numerics = handle->check_numerics;
+        rocblas_internal_logger logger;
         if(layer_mode & rocblas_layer_mode_log_trace)
-            log_trace(handle,
-                      rocblas_ger_strided_batched_name<CONJ, T>,
-                      m,
-                      n,
-                      LOG_TRACE_SCALAR_VALUE(handle, alpha),
-                      x,
-                      incx,
-                      stridex,
-                      y,
-                      incy,
-                      stridey,
-                      A,
-                      lda,
-                      strideA,
-                      batch_count);
+            logger.log_trace(handle,
+                             rocblas_ger_strided_batched_name<CONJ, T>,
+                             m,
+                             n,
+                             LOG_TRACE_SCALAR_VALUE(handle, alpha),
+                             x,
+                             incx,
+                             stridex,
+                             y,
+                             incy,
+                             stridey,
+                             A,
+                             lda,
+                             strideA,
+                             batch_count);
 
         if(layer_mode & rocblas_layer_mode_log_bench)
-            log_bench(handle,
-                      ROCBLAS_API_BENCH " -f",
-                      rocblas_ger_strided_batched_fn_name<CONJ, T>,
-                      "-r",
-                      rocblas_precision_string<T>,
-                      "-m",
-                      m,
-                      "-n",
-                      n,
-                      LOG_BENCH_SCALAR_VALUE(handle, alpha),
-                      "--incx",
-                      incx,
-                      "--stride_x",
-                      stridex,
-                      "--incy",
-                      incy,
-                      "--stride_y",
-                      stridey,
-                      "--lda",
-                      lda,
-                      "--stride_a",
-                      strideA,
-                      "--batch_count",
-                      batch_count);
+            logger.log_bench(handle,
+                             ROCBLAS_API_BENCH " -f",
+                             rocblas_ger_strided_batched_fn_name<CONJ, T>,
+                             "-r",
+                             rocblas_precision_string<T>,
+                             "-m",
+                             m,
+                             "-n",
+                             n,
+                             LOG_BENCH_SCALAR_VALUE(handle, alpha),
+                             "--incx",
+                             incx,
+                             "--stride_x",
+                             stridex,
+                             "--incy",
+                             incy,
+                             "--stride_y",
+                             stridey,
+                             "--lda",
+                             lda,
+                             "--stride_a",
+                             strideA,
+                             "--batch_count",
+                             batch_count);
 
         if(layer_mode & rocblas_layer_mode_log_profile)
-            log_profile(handle,
-                        rocblas_ger_strided_batched_name<CONJ, T>,
-                        "M",
-                        m,
-                        "N",
-                        n,
-                        "incx",
-                        incx,
-                        "stride_x",
-                        stridex,
-                        "incy",
-                        incy,
-                        "stride_y",
-                        stridey,
-                        "lda",
-                        lda,
-                        "stride_a",
-                        strideA,
-                        "batch_count",
-                        batch_count);
+            logger.log_profile(handle,
+                               rocblas_ger_strided_batched_name<CONJ, T>,
+                               "M",
+                               m,
+                               "N",
+                               n,
+                               "incx",
+                               incx,
+                               "stride_x",
+                               stridex,
+                               "incy",
+                               incy,
+                               "stride_y",
+                               stridey,
+                               "lda",
+                               lda,
+                               "stride_a",
+                               strideA,
+                               "batch_count",
+                               batch_count);
 
         rocblas_status arg_status = rocblas_ger_arg_check<API_INT, CONJ, T>(handle,
                                                                             m,
