@@ -1,5 +1,5 @@
 /* ************************************************************************
- * Copyright (C) 2024 Advanced Micro Devices, Inc. All rights reserved.
+ * Copyright (C) 2024-2025 Advanced Micro Devices, Inc. All rights reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -19,6 +19,7 @@
  * CTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  *
  * ************************************************************************ */
+#pragma once
 
 #include "handle.hpp"
 #include "int64_helpers.hpp"
@@ -72,7 +73,8 @@ namespace
         if(!handle)
             return rocblas_status_invalid_handle;
 
-        auto check_numerics = handle->check_numerics;
+        auto                    check_numerics = handle->check_numerics;
+        rocblas_internal_logger logger;
         /////////////
         // LOGGING //
         /////////////
@@ -89,69 +91,69 @@ namespace
                 auto diag_letter   = rocblas_diag_letter(diag);
 
                 if(layer_mode & rocblas_layer_mode_log_trace)
-                    log_trace(handle,
-                              rocblas_trsm_name<T>,
-                              side,
-                              uplo,
-                              transA,
-                              diag,
-                              m,
-                              n,
-                              LOG_TRACE_SCALAR_VALUE(handle, alpha),
-                              A,
-                              lda,
-                              B,
-                              ldb,
-                              batch_count);
+                    logger.log_trace(handle,
+                                     rocblas_trsm_name<T>,
+                                     side,
+                                     uplo,
+                                     transA,
+                                     diag,
+                                     m,
+                                     n,
+                                     LOG_TRACE_SCALAR_VALUE(handle, alpha),
+                                     A,
+                                     lda,
+                                     B,
+                                     ldb,
+                                     batch_count);
 
                 if(layer_mode & rocblas_layer_mode_log_bench)
                 {
-                    log_bench(handle,
-                              ROCBLAS_API_BENCH " -f trsm_batched -r",
-                              rocblas_precision_string<T>,
-                              "--side",
-                              side_letter,
-                              "--uplo",
-                              uplo_letter,
-                              "--transposeA",
-                              transA_letter,
-                              "--diag",
-                              diag_letter,
-                              "-m",
-                              m,
-                              "-n",
-                              n,
-                              LOG_BENCH_SCALAR_VALUE(handle, alpha),
-                              "--lda",
-                              lda,
-                              "--ldb",
-                              ldb,
-                              "--batch_count",
-                              batch_count);
+                    logger.log_bench(handle,
+                                     ROCBLAS_API_BENCH " -f trsm_batched -r",
+                                     rocblas_precision_string<T>,
+                                     "--side",
+                                     side_letter,
+                                     "--uplo",
+                                     uplo_letter,
+                                     "--transposeA",
+                                     transA_letter,
+                                     "--diag",
+                                     diag_letter,
+                                     "-m",
+                                     m,
+                                     "-n",
+                                     n,
+                                     LOG_BENCH_SCALAR_VALUE(handle, alpha),
+                                     "--lda",
+                                     lda,
+                                     "--ldb",
+                                     ldb,
+                                     "--batch_count",
+                                     batch_count);
                 }
 
                 if(layer_mode & rocblas_layer_mode_log_profile)
                 {
-                    log_profile(handle,
-                                rocblas_trsm_name<T>,
-                                "side",
-                                side_letter,
-                                "uplo",
-                                uplo_letter,
-                                "transA",
-                                transA_letter,
-                                "diag",
-                                diag_letter,
-                                "m",
-                                m,
-                                "n",
-                                n,
-                                "lda",
-                                lda,
-                                "ldb",
-                                ldb,
-                                "batch_count",
-                                batch_count);
+                    logger.log_profile(handle,
+                                       rocblas_trsm_name<T>,
+                                       "side",
+                                       side_letter,
+                                       "uplo",
+                                       uplo_letter,
+                                       "transA",
+                                       transA_letter,
+                                       "diag",
+                                       diag_letter,
+                                       "m",
+                                       m,
+                                       "n",
+                                       n,
+                                       "lda",
+                                       lda,
+                                       "ldb",
+                                       ldb,
+                                       "batch_count",
+                                       batch_count);
                 }
             }
         }
@@ -254,7 +256,7 @@ namespace
                                                                          0,
                                                                          0);
             status = (status != rocblas_status_success) ? status : perf_status;
-            if(status != rocblas_status_success)
+            if(status != rocblas_status_success && status != rocblas_status_perf_degraded)
                 return status;
         }
 
