@@ -1,5 +1,5 @@
 /* ************************************************************************
- * Copyright (C) 2016-2024 Advanced Micro Devices, Inc. All rights reserved.
+ * Copyright (C) 2016-2025 Advanced Micro Devices, Inc. All rights reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -69,6 +69,7 @@ namespace
         if(!HPA)
             RETURN_ZERO_DEVICE_MEMORY_SIZE_IF_QUERIED(handle);
 
+        rocblas_internal_logger logger;
         // Copy alpha and beta to host if on device
         rocblas_union_t alpha_h, beta_h;
         RETURN_IF_ROCBLAS_ERROR(rocblas_copy_alpha_beta_to_host_if_on_device(
@@ -99,151 +100,147 @@ namespace
                 {
                     rocblas_internal_ostream alphass, betass;
 
-                    if(log_trace_alpha_beta_ex(compute_type, alpha, beta, alphass, betass)
-                       == rocblas_status_success)
-                    {
-                        log_trace(handle,
-                                  ROCBLAS_API_STR(rocblas_gemm_strided_batched_ex),
-                                  trans_a,
-                                  trans_b,
-                                  m,
-                                  n,
-                                  k,
-                                  alphass.str(),
-                                  a,
-                                  a_type_string,
-                                  lda,
-                                  stride_a,
-                                  b,
-                                  b_type_string,
-                                  ldb,
-                                  stride_b,
-                                  betass.str(),
-                                  c,
-                                  c_type_string,
-                                  ldc,
-                                  stride_c,
-                                  d,
-                                  d_type_string,
-                                  ldd,
-                                  stride_d,
-                                  batch_count,
-                                  compute_type_string,
-                                  algo,
-                                  solution_index,
-                                  rocblas_gemm_flags(flags));
-                    }
+                    (void)rocblas_internal_log_trace_alpha_beta_ex(
+                        compute_type, alpha, beta, alphass, betass);
+                    logger.log_trace(handle,
+                                     ROCBLAS_API_STR(rocblas_gemm_strided_batched_ex),
+                                     trans_a,
+                                     trans_b,
+                                     m,
+                                     n,
+                                     k,
+                                     alphass.str(),
+                                     a,
+                                     a_type_string,
+                                     lda,
+                                     stride_a,
+                                     b,
+                                     b_type_string,
+                                     ldb,
+                                     stride_b,
+                                     betass.str(),
+                                     c,
+                                     c_type_string,
+                                     ldc,
+                                     stride_c,
+                                     d,
+                                     d_type_string,
+                                     ldd,
+                                     stride_d,
+                                     batch_count,
+                                     compute_type_string,
+                                     algo,
+                                     solution_index,
+                                     rocblas_gemm_flags(flags));
                 }
 
                 if(layer_mode & rocblas_layer_mode_log_bench)
                 {
                     std::string alphas, betas;
-                    if(log_bench_alpha_beta_ex(compute_type, alpha, beta, alphas, betas)
-                       == rocblas_status_success)
-                    {
-                        log_bench(handle,
-                                  ROCBLAS_API_BENCH " -f gemm_strided_batched_ex",
-                                  "--transposeA",
-                                  trans_a_letter,
-                                  "--transposeB",
-                                  trans_b_letter,
-                                  "-m",
-                                  m,
-                                  "-n",
-                                  n,
-                                  "-k",
-                                  k,
-                                  alphas,
-                                  "--a_type",
-                                  a_type_string,
-                                  "--lda",
-                                  lda,
-                                  "--stride_a",
-                                  stride_a,
-                                  "--b_type",
-                                  b_type_string,
-                                  "--ldb",
-                                  ldb,
-                                  "--stride_b",
-                                  stride_b,
-                                  betas,
-                                  "--c_type",
-                                  c_type_string,
-                                  "--ldc",
-                                  ldc,
-                                  "--stride_c",
-                                  stride_c,
-                                  "--d_type",
-                                  d_type_string,
-                                  "--ldd",
-                                  ldd,
-                                  "--stride_d",
-                                  stride_d,
-                                  "--batch_count",
-                                  batch_count,
-                                  "--compute_type",
-                                  compute_type_string,
-                                  "--algo",
-                                  algo,
-                                  "--solution_index",
-                                  solution_index,
-                                  "--flags",
-                                  flags);
-                    }
+                    (void)rocblas_internal_log_bench_alpha_beta_ex(
+                        compute_type, alpha, beta, alphas, betas);
+                    logger.log_bench(handle,
+                                     ROCBLAS_API_BENCH " -f gemm_strided_batched_ex",
+                                     "--transposeA",
+                                     trans_a_letter,
+                                     "--transposeB",
+                                     trans_b_letter,
+                                     "-m",
+                                     m,
+                                     "-n",
+                                     n,
+                                     "-k",
+                                     k,
+                                     alphas,
+                                     "--a_type",
+                                     a_type_string,
+                                     "--lda",
+                                     lda,
+                                     "--stride_a",
+                                     stride_a,
+                                     "--b_type",
+                                     b_type_string,
+                                     "--ldb",
+                                     ldb,
+                                     "--stride_b",
+                                     stride_b,
+                                     betas,
+                                     "--c_type",
+                                     c_type_string,
+                                     "--ldc",
+                                     ldc,
+                                     "--stride_c",
+                                     stride_c,
+                                     "--d_type",
+                                     d_type_string,
+                                     "--ldd",
+                                     ldd,
+                                     "--stride_d",
+                                     stride_d,
+                                     "--batch_count",
+                                     batch_count,
+                                     "--compute_type",
+                                     compute_type_string,
+                                     "--algo",
+                                     algo,
+                                     "--solution_index",
+                                     solution_index,
+                                     "--flags",
+                                     flags);
                 }
 
                 if(layer_mode & rocblas_layer_mode_log_profile)
                 {
-                    log_profile(handle,
-                                ROCBLAS_API_STR(rocblas_gemm_strided_batched_ex),
-                                "a_type",
-                                a_type_string,
-                                "b_type",
-                                b_type_string,
-                                "c_type",
-                                c_type_string,
-                                "d_type",
-                                d_type_string,
-                                "compute_type",
-                                compute_type_string,
-                                "transA",
-                                trans_a_letter,
-                                "transB",
-                                trans_b_letter,
-                                "M",
-                                m,
-                                "N",
-                                n,
-                                "K",
-                                k,
-                                "alpha",
-                                value_category(alpha, compute_type),
-                                "lda",
-                                lda,
-                                "stride_a",
-                                stride_a,
-                                "ldb",
-                                ldb,
-                                "stride_b",
-                                stride_b,
-                                "beta",
-                                value_category(beta, compute_type),
-                                "ldc",
-                                ldc,
-                                "stride_c",
-                                stride_c,
-                                "ldd",
-                                ldd,
-                                "stride_d",
-                                stride_d,
-                                "batch_count",
-                                batch_count,
-                                "algo",
-                                algo,
-                                "solution_index",
-                                solution_index,
-                                "flags",
-                                rocblas_gemm_flags(flags));
+                    logger.log_profile(handle,
+                                       ROCBLAS_API_STR(rocblas_gemm_strided_batched_ex),
+                                       "a_type",
+                                       a_type_string,
+                                       "b_type",
+                                       b_type_string,
+                                       "c_type",
+                                       c_type_string,
+                                       "d_type",
+                                       d_type_string,
+                                       "compute_type",
+                                       compute_type_string,
+                                       "transA",
+                                       trans_a_letter,
+                                       "transB",
+                                       trans_b_letter,
+                                       "M",
+                                       m,
+                                       "N",
+                                       n,
+                                       "K",
+                                       k,
+                                       "alpha",
+                                       rocblas_internal_value_category(alpha, compute_type),
+                                       "lda",
+                                       lda,
+                                       "stride_a",
+                                       stride_a,
+                                       "ldb",
+                                       ldb,
+                                       "stride_b",
+                                       stride_b,
+                                       "beta",
+                                       rocblas_internal_value_category(beta, compute_type),
+                                       "ldc",
+                                       ldc,
+                                       "stride_c",
+                                       stride_c,
+                                       "ldd",
+                                       ldd,
+                                       "stride_d",
+                                       stride_d,
+                                       "batch_count",
+                                       batch_count,
+                                       "algo",
+                                       algo,
+                                       "solution_index",
+                                       solution_index,
+                                       "flags",
+                                       rocblas_gemm_flags(flags));
                 }
             }
         }
